python-tunnelclient
====================

Tunnel client for OpenStack Vpn Servering

This is an OpenStack Client (OSC) plugin for Tunnel, an OpenStack
Vpn Servering project.


Getting Started
===============

.. note:: This is an OpenStack Client plugin. The ``python-openstackclient``
          project should be installed to use this plugin.

Tunnel client can be installed from PyPI using pip

.. code-block:: bash

    pip install python-tunnelclient

If you want to make changes to the Tunnel client for testing and contribution,
make any changes and then run

.. code-block:: bash

    python setup.py develop

or

.. code-block:: bash

    pip install -e .
